#!/bin/bash

cd `dirname $0`/src
./bluemindo.py "$@"